@@ -11,7 +11,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "fdbe98851347ecff",
+    "AWS::ARCRegionSwitch::Plan": "157873619ca0d0eb",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -83,8 +83,8 @@ types: dict[str, str] = {
     "AWS::Athena::DataCatalog": "72b7e9ce721875ee",
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
-    "AWS::Athena::WorkGroup": "15b478b9836a0d48",
-    "AWS::AutoScaling::AutoScalingGroup": "1176577a6acfd8f9",
+    "AWS::Athena::WorkGroup": "98125aa523006e5f",
+    "AWS::AutoScaling::AutoScalingGroup": "8fe2b009cdacf409",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -232,7 +232,7 @@ types: dict[str, str] = {
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
     "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
-    "AWS::EC2::CapacityReservation": "5b0dc1ffda2169f7",
+    "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
     "AWS::EC2::ClientVpnAuthorizationRule": "09dec539b3c3f428",
     "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
@@ -254,7 +254,7 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "51763c48d327df98",
+    "AWS::EC2::Instance": "a922ff4a1cb10687",
     "AWS::EC2::InstanceConnectEndpoint": "aff65ea38d1b25dc",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
@@ -335,13 +335,13 @@ types: dict[str, str] = {
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
-    "AWS::ECR::RepositoryCreationTemplate": "260745c34d057c07",
+    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
     "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
-    "AWS::ECS::Service": "75313434fba04f66",
+    "AWS::ECS::Service": "585001d48158728c",
     "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
     "AWS::ECS::TaskSet": "93284b06523a426d",
     "AWS::EFS::AccessPoint": "2f62161de474e688",
@@ -363,6 +363,7 @@ types: dict[str, str] = {
     "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
     "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
     "AWS::EMRServerless::Application": "b8f0bd50831c9f1e",
+    "AWS::EVS::Environment": "8cbba6115db38908",
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
@@ -392,7 +393,7 @@ types: dict[str, str] = {
     "AWS::Events::EventBus": "87abb79a2ea2a571",
     "AWS::Events::EventBusPolicy": "7cb0a2b18483bb52",
     "AWS::Events::Rule": "4b8efe4a7f81f66f",
-    "AWS::FMS::NotificationChannel": "622ce9589b28d75d",
+    "AWS::FMS::NotificationChannel": "8562504583cd6ad4",
     "AWS::FMS::Policy": "3d3868b1e974d27b",
     "AWS::FMS::ResourceSet": "6fb04db2dcf50bf8",
     "AWS::FSx::DataRepositoryAssociation": "2c944a4b33c2d639",
@@ -472,7 +473,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "b6f9713f56922d8c",
+    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
@@ -508,7 +509,7 @@ types: dict[str, str] = {
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
     "AWS::Logs::ResourcePolicy": "d7898253a7730ac3",
     "AWS::Logs::SubscriptionFilter": "57635d7dc5bd3e61",
-    "AWS::Logs::Transformer": "4d1796b2fa0445b0",
+    "AWS::Logs::Transformer": "66b4b09c596d83c0",
     "AWS::MSK::BatchScramSecret": "ff2b807a577495b0",
     "AWS::MSK::Cluster": "07d7025a3ae5e3bb",
     "AWS::MSK::ClusterPolicy": "b60740da22ea8c04",
@@ -596,7 +597,7 @@ types: dict[str, str] = {
     "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
     "AWS::Pipes::Pipe": "052457cd8332df71",
     "AWS::RAM::Permission": "740a6e8ada63a5a3",
-    "AWS::RAM::ResourceShare": "301739e35a5f7f66",
+    "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
     "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
@@ -650,7 +651,7 @@ types: dict[str, str] = {
     "AWS::Route53Resolver::FirewallRuleGroupAssociation": "d84c68a6ebbb5876",
     "AWS::Route53Resolver::ResolverConfig": "174be26547caaa42",
     "AWS::Route53Resolver::ResolverDNSSECConfig": "813fd8fe1e24c6e3",
-    "AWS::Route53Resolver::ResolverEndpoint": "8d7bd275c544d896",
+    "AWS::Route53Resolver::ResolverEndpoint": "d0ad42bf85f59279",
     "AWS::Route53Resolver::ResolverQueryLoggingConfig": "78d814f813fdbcbf",
     "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation": "41e93f940f8bce93",
     "AWS::Route53Resolver::ResolverRule": "a5bf3dc0f2b44d80",
@@ -659,7 +660,7 @@ types: dict[str, str] = {
     "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
     "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "1aa877c9b86f9e89",
+    "AWS::S3::Bucket": "bc2a891a463ee5ee",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3::MultiRegionAccessPoint": "193323be1bf2dac0",
     "AWS::S3::MultiRegionAccessPointPolicy": "7ac84076052ddd16",
@@ -686,6 +687,7 @@ types: dict[str, str] = {
     "AWS::SES::MailManagerTrafficPolicy": "e229aa555378d193",
     "AWS::SES::MultiRegionEndpoint": "23f0206212864cb3",
     "AWS::SES::Template": "20af669206370beb",
+    "AWS::SES::Tenant": "0c003f20faaf4446",
     "AWS::SES::VdmAttributes": "15df0379061c0489",
     "AWS::SMSVOICE::ConfigurationSet": "2bdda88e956e2a26",
     "AWS::SMSVOICE::OptOutList": "005f2438fbf815f8",
@@ -704,8 +706,8 @@ types: dict[str, str] = {
     "AWS::SSM::Association": "ad263c9023f92e0c",
     "AWS::SSM::Document": "8b3a8b629d6edee1",
     "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
-    "AWS::SSM::MaintenanceWindowTarget": "67da7a687adc34fb",
-    "AWS::SSM::MaintenanceWindowTask": "bdd479736cab2d77",
+    "AWS::SSM::MaintenanceWindowTarget": "16bcb928c1d2233d",
+    "AWS::SSM::MaintenanceWindowTask": "ce68f32e2ef0a575",
     "AWS::SSM::Parameter": "c247b226112c5ae5",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
